StreamBody

Struct StreamBody 

pub struct StreamBody<T> { /* private fields */ }
Bidirectional adapter between Stream and Body at the Frame level:

  • When the inner value implements Body, this type implements Stream yielding Result<Frame<Body::Data>, Body::Error>.
  • When the inner value implements Stream, this type implements Body forwarding each Result<Frame<D>, E> frame as-is.

Implementations

Source

impl<T> StreamBody<T>

pub fn new(value: T) -> Self